@@ -36,8 +36,8 @@ namespace log4cpp {
         return message.str();
     }
 
-    std::auto_ptr<Layout> create_basic_layout(const FactoryParams& params)
+    std::LOG4CPP_UNIQUE_PTR<Layout> create_basic_layout(const FactoryParams& params)
     {
-       return std::auto_ptr<Layout>(new BasicLayout);
+       return std::LOG4CPP_UNIQUE_PTR<Layout>(new BasicLayout);
     }
 }
