@@ -7,7 +7,7 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include <log4cpp/Portability.hh>
+#include "PortabilityImpl.hh"
 #if LOG4CPP_HAVE_SYSLOG
 
 #include <unistd.h>
@@ -15,6 +15,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <log4cpp/SyslogAppender.hh>
+#include <log4cpp/FactoryParams.hh>
+#include <memory>
 
 namespace log4cpp {
 
@@ -62,7 +64,7 @@ namespace log4cpp {
     }
 
     void SyslogAppender::_append(const LoggingEvent& event) {
-	std::string message(_getLayout().format(event));
+        std::string message(_getLayout().format(event));
         int priority = toSyslogPriority(event.priority);
         ::syslog(priority | _facility, "%s", message.c_str());
     }
@@ -72,6 +74,15 @@ namespace log4cpp {
         open();
         return true;
     }
+    
+    std::LOG4CPP_UNIQUE_PTR<Appender> create_syslog_appender(const FactoryParams& params)
+    {
+       std::string name, syslog_name;
+       int facility = 0;
+       params.get_for("syslog appender").required("name", name)("syslog_name", syslog_name)
+                                        .optional("facility", facility);
+       return std::LOG4CPP_UNIQUE_PTR<Appender>(new SyslogAppender(name, syslog_name, facility));
+    }
 }
 
 #endif // LOG4CPP_HAVE_SYSLOG
